# mathew [![PyPI version](https://badge.fury.io/py/mathew.svg)](https://pypi.python.org/pypi/mathew/) [![PyPI license](https://img.shields.io/pypi/l/mathew.svg)](https://pypi.python.org/pypi/mathew/)
 
A collection of math function I need for several of my projects

## Currently supports
- Primes
- Vectorgeometry
- Some helper functions
